@@ -1,14 +1,10 @@
-from .version import *
-
-
 # Apply patch only if django is installed
 try:
     from django.core.exceptions import ImproperlyConfigured
     try:
-        from django.db import models
-        from .filters.patch import *
-        from .models.patch import *
-        from .forms.patch import *
+        from django.db import models  # noqa: F401
+        from .models import patch as model_patch  # noqa: F401
+        from .forms import patch as form_patch  # noqa: F401
     except ImproperlyConfigured:
         pass
 except ImportError:
